summaryrefslogtreecommitdiff
path: root/tests/common/helpers.h
diff options
context:
space:
mode:
Diffstat (limited to 'tests/common/helpers.h')
-rw-r--r--tests/common/helpers.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/common/helpers.h b/tests/common/helpers.h
index 81aa79c..3576d93 100644
--- a/tests/common/helpers.h
+++ b/tests/common/helpers.h
@@ -181,9 +181,9 @@ bool SearchFileForString(const std::string &path, const std::string &substring);
int double_cmp(double a, double b, int precision = 2);
/**
* Select for the list of events given in the varargs. Last element must be
* -1.
*/
-void SelectXI2Events(Display *dpy, int deviceid, Window win, ...);
+void SelectXI2Events(Display *dpy, int deviceid, Window win,
+ const std::vector<int>& evtypes);
#endif
@@ -181,9 +181,9 @@ bool SearchFileForString(const std::string &path, const std::string &substring);
int double_cmp(double a, double b, int precision = 2);
/**
- * Select for the list of events given in the varargs. Last element must be
- * -1.
+ * Select for the list of events given in the evtypes.
*/